<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Marijn Hofstra hofstra.m@gmail.com
 * @author Matthias Carchon webmaster@c-mattic.be
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 * @author Remon <no@email.local>
 * @author Rene <wllywlnt@yahoo.com>
 */
$lang['menu']                  = 'Herstel';
$lang['filter']                = 'Zoek naar bekladde pagina\'s';
$lang['revert']                = 'Herstel geselecteerde pagina\'s';
$lang['reverted']              = '%s hersteld naar revisie %s';
$lang['removed']               = '%s verwijderd';
$lang['revstart']              = 'Herstelproces is begonnen. Dit kan een lange tijd duren. Als het script een timeout genereert voor het klaar is, moet je in kleinere delen herstellen.';
$lang['revstop']               = 'Herstelproces succesvol afgerond.';
$lang['note1']                 = 'NB: deze zoekopdracht is hoofdlettergevoelig';
$lang['note2']                 = 'NB: de pagina zal hersteld worden naar de laatste versie waar de opgegeven spam-term <i>%s</i> niet op voorkomt.';
